Struct
EBookContactsContactCert
Functions
e_contact_cert_from_attr
Creates a new EContactCert structure with the information
from the source attribute. Returns NULL, when
the information in the source could not be stored
in the structure (for example when the KEY attribute
is a URI to some server).
unstable since: 3.60
Instance methods
e_contact_cert_write_attr
Populates the destination with the data from the self,
using format suitable to to_version vCard version. The
function does nothing when the self is an empty structure. The destination is supposed to be a KEY attribute.
unstable since: 3.60